MessageConfig class

Constructors

MessageConfig({bool isGetMessageListBeforeJoinGroup = false, bool showNickName = true, bool showTitle = true, bool isUseGroupCounter = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isGetMessageListBeforeJoinGroup ↔ bool
latefinal
isUseGroupCounter ↔ bool
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showNickName ↔ bool
latefinal
showTitle ↔ bool
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited