TencentCloudAvChatRoomController class
- Inheritance
-
- Object
- ChangeNotifier
- TencentCloudAvChatRoomController
Constructors
Properties
- actionType ↔ TencentCloudAvChatRoomControllerActionType
-
getter/setter pair
- animationUrl → String
-
no setter
- giftData → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- liveKitData → TencentCloudAvChatRoomData?
-
no setter
- message → V2TimMessage?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textString → String
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
playAnimation(
String url) → dynamic -
play animation
The
urlparamter support lottie json file and svga file. ifurlstart with http will play network animation. -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendGiftMessage(
String data) → dynamic - send gift message.
-
sendMessage(
V2TimMessage message) → dynamic - send message. Need use tencent im sdk plugin to create message.
-
sendTextMessage(
String text, String roomID) → dynamic - send text message.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateData(
TencentCloudAvChatRoomData data) → dynamic - update live kit releated data.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited