playAnimation method
play animation
The url paramter support lottie json file and svga file.
if url start with http will play network animation.
Implementation
playAnimation(String url) {
actionType = TencentCloudAvChatRoomControllerActionType.playAnimation;
_animationUrl = url;
notifyListeners();
}